Startseite - DDL-Board.org (4.0)

Sie sind nicht angemeldet.

- Anmelden
- Registrieren

- Ungelesene Beiträge
- Unbeantwortete Themen
- Themen der letzten 24 Stunden
- Erweiterte Suche

# DDL-Board.org (4.0)

- Portal
- Forum
- Adventkalender
- DDL-Network
  - DDL-Warez
  - DDL-Music
- Vote

## DDL-Board.org (4.0)

Forum von DDL-Network

Im Dezember gibt es bei uns wieder Türchen zu öffnen! Hier mitmachen

Lieber Besucher, herzlich willkommen bei: DDL-Board.org (4.0). Falls dies Ihr erster Besuch auf dieser Seite ist, lesen Sie sich bitte die Hilfe durch. Dort wird Ihnen die Bedienung dieser Seite näher erläutert. Darüber hinaus sollten Sie sich registrieren, um alle Funktionen dieser Seite nutzen zu können. Benutzen Sie das Registrierungsformular, um sich zu registrieren oder informieren Sie sich ausführlich über den Registrierungsvorgang. Falls Sie sich bereits zu einem früheren Zeitpunkt registriert haben, können Sie sich hier anmelden.

### Neuigkeiten (6)

- Themen (6)

| Guest only - Guest helps Guest |  | [Problem] Sicherheitscode weg Von Chekov (Gestern, 20:32) | Von MR Download (Gestern, 23:07)
| Guest only - Guest helps Guest |  | [Problem] Lexware Kassenbuch 2014 keine Serial Von Maskara (Gestern, 17:06) | keine Antwort
| Guest only - Guest helps Guest |  | [Problem] Microsoft.Windows.8.1.Pro.German.x64.Integrated.November.2014-FKY Von ed (30. November 2014, 19:38) | Von MCUpper (7. Dezember 2014, 15:31)
| Guest only - Hinweise & Tipps |  | Alle Jahre wieder öffnen wir die Türen... Von CompiOpi (7. Dezember 2014, 15:24) | keine Antwort
| Guest only - Guest helps Guest |  | [Erledigt] Captcha Problem Von The_Bad (7. Dezember 2014, 03:59) | Von The_Bad (7. Dezember 2014, 09:37)
| Guest only - Guest helps Guest |  | [Problem] Alben nicht vorhanden Von Cannabis = beste Medizin (6. Dezember 2014, 20:16) | keine Antwort

- Ungelesene Beiträge
- Themen der letzten 24 Stunden

Die letzten 10 Beiträge

Guest only - Hinweise & Tipps » | Alle Jahre wieder öffnen wir die Türen... | Von CompiOpi (7. Dezember 2014, 15:24)
Guest only - Hinweise & Tipps » | Wie entpacke ich richtig & Was tun bei CRC-Fehlern | Von Smith (14. Oktober 2011, 19:10)
Guest only - Hinweise & Tipps » | Anbieten von eigenen Uploads & Suchanfragen für Uploads | Von Smith (14. Oktober 2011, 19:03)
Guest only - Hinweise & Tipps » | Support Maske richtig ausfüllen | Von Smith (14. Oktober 2011, 19:01)
Guest only - Hinweise & Tipps » | Wo finde ich Antworten auf meine Fragen? |... | Von Smith (14. Oktober 2011, 18:52)
Guest only - Hinweise & Tipps » | Nützliche Links | Von SYSTEM (15. April 2010, 12:30)
Guest only - Hinweise & Tipps » | Wichtige Hinweise bei Problemen - erstmal lesen!! | Von SYSTEM (6. November 2009, 17:06)

Anmelden:

- ### Unauthorized Zone

  Gästebereich für Kommentare und Hinweise zu ddl - Beiträge werden kontrolliert und können bei Bedarf kommentarlos gelöscht werden.

  - #### Guest only - Hinweise & Tipps (1)

    - Hier erhält man Tipps und Hinweise -
    Eigene Beiträge sind nicht möglich.

    Severus, Smith

    Alle Jahre wieder öffnen wir die Türen...

    Von CompiOpi (7. Dezember 2014, 15:24)

    Themen
      7
    Beiträge
      9

  - #### Guest only - Guest helps Guest (6)

    - Fragen zu Main-Uploads. Anderes wird kommentarlos entfernt! - Also KEINE DOWN-Meldungen!!!
    Virenmeldungen unbedingt per virustotal.com-Log belegen!

    Severus, Smith

    [Problem] Sicherheitscode weg

    Von MR Download (Gestern, 23:07)

    Themen
      63
    Beiträge
      156

  - #### Guest only - Downs

    -NUR Downs melden! Für Hardwaredefekte sind wir nicht zuständig- Die Fehlermeldung "Die Verknüpfung zum Download konnte nicht hergestellt werden." weist auf einen temporären HDD/Serverfehler hin!

    Severus, Smith

    [DOWN-Warez] Das.Wandelnde.Schloss.2004.German.DL.720p.BluRay.x264-STARS DOWN

    Von Carlos (5. Dezember 2014, 19:56)

    Themen
      5
    Beiträge
      97

### Zurzeit sind 4 Benutzer online:

3 Mitglieder (davon 1 unsichtbar) und 1 Besucher - Rekord: 127 Benutzer (Sonntag, 1. August 2010, 14:45)

Bieronie, Lui666

Legende: Administratoren, Co-Admin, S-Mod, Mod-DDLW, Mod-Music , VIM, Upper-Music, Upper-Warez, Technik

### Statistik:

7 485 Mitglieder - 9 257 Themen - 48 133 Beiträge (19,69 Beiträge pro Tag)
Unser neuestes Mitglied heißt: ropopow.

### Legende:

Forum enthält keine neuen Beiträge
Forum enthält neue Beiträge
Forum ist geschlossen
Forum ist ein externer Link

### Die beliebtesten Tags

- 1080p
- 720p
- Adobe
- Anime
- Chrome
- Cover
- Crack
- crf
- DOWN
- Download
- Fehler
- film
- Game
- Games
- Grafik
- grafikkarte
- Hilfe
- Iphone
- itunes
- JDownloader
- Kino
- Mac
- Metal
- Movie
- mp3
- Musik
- Navi
- neu
- One Piece
- PC
- pdf
- Playstation
- pro
- Problem
- PS3
- Samsung
- scene
- Serie
- Share-online
- Software
- Spiele
- Staffel
- studio
- Supernatural
- TV
- video2brain
- Vorschlag
- 3
- Wimmelbild
- 2012

Alle Foren als gelesen markieren

Dauerhaft angemeldet bleiben?